netapp_ontap.models.fpolicy_engines API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fpolicy_engines`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FpolicyEnginesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FpolicyEngines object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `buffer_size: FpolicyEngineBufferSize GET POST PATCH`

    Specifies the send and receive buffer size of the connected socket for the FPolicy server.

  `certificate: FpolicyEngineCertificate GET POST PATCH`

    Provides details about certificate used to authenticate the FPolicy server.

  `format: str GET POST PATCH`

    The format for the notification messages sent to the FPolicy servers. The possible values are:

        * xml  - Notifications sent to the FPolicy server will be formatted using the XML schema.
        * protobuf - Notifications sent to the FPolicy server will be formatted using Protobuf schema, which is a binary form.

    Valid choices:

    - xml
    - protobuf
  `keep_alive_interval: str GET POST PATCH`

    Specifies the ISO-8601 interval time for a storage appliance to send Keep Alive message to an FPolicy server. The allowed range is between 10 to 600 seconds.

    Example: PT2M

  `max_connection_retries: Size GET POST PATCH`

    This parameter specifies the maximum number of attempts to reconnect to the FPolicy server from an SVM. It is used to specify the number of times a broken connection will be retried. The value for this field must be between 0 and 20. By default, it is 5.

    Example: 5

  `max_server_requests: Size GET POST PATCH`

    Specifies the maximum number of outstanding requests for the FPolicy server. It is used to specify maximum outstanding requests that will be queued up for the FPolicy server. The value for this field must be between 1 and 10000. The default values are 500, 1000 or 2000 for Low-end(<64 GB memory), Mid-end(>=64 GB memory) and High-end(>=128 GB memory) Platforms respectively.

    Example: 500

  `name: str GET POST`

    Specifies the name to assign to the external server configuration.

    Example: fp_ex_eng

  `port: Size GET POST PATCH`

    Port number of the FPolicy server application.

    Example: 9876

  `primary_servers: List[str] GET POST PATCH`

    The primary_servers field of the fpolicy_engines.

    Example: ["10.132.145.20","10.140.101.109"]

  `request_abort_timeout: str GET POST PATCH`

    Specifies the ISO-8601 timeout duration for a screen request to be aborted by a storage appliance. The allowed range is between 0 to 200 seconds.

    Example: PT40S

  `request_cancel_timeout: str GET POST PATCH`

    Specifies the ISO-8601 timeout duration for a screen request to be processed by an FPolicy server. The allowed range is between 0 to 100 seconds.

    Example: PT20S

  `resiliency: FpolicyEngineResiliency GET POST PATCH`

    If all primary and secondary servers are down, or if no response is received from the FPolicy servers, file access events are stored inside the storage controller under the specified resiliency-directory-path.

  `secondary_servers: List[str] GET POST PATCH`

    The secondary_servers field of the fpolicy_engines.

    Example: ["10.132.145.20","10.132.145.21"]

  `server_progress_timeout: str GET POST PATCH`

    Specifies the ISO-8601 timeout duration in which a throttled FPolicy server must complete at least one screen request. If no request is processed within the timeout, connection to the FPolicy server is terminated. The allowed range is between 0 to 100 seconds.

    Example: PT1M

  `session_timeout: str GET POST PATCH`

    This parameter specifies the interval after which a new session ID is sent to the FPolicy server during reconnection attempts. The default value is set to 10 seconds. If the connection between the storage controller and the FPolicy server is terminated and reconnection is made within the -session-timeout interval, the old session ID is sent to the FPolicy server so that it can send responses for old notifications.

    Example: PT10S

  `ssl_option: str GET POST PATCH`

    Specifies the SSL option for external communication with the FPolicy server. Possible values include the following:

    - no_auth When set to "no_auth", no authentication takes place.
    - server_auth When set to "server_auth", only the FPolicy server is authenticated by the SVM. With this option, before creating the FPolicy external engine, the administrator must install the public certificate of the certificate authority (CA) that signed the FPolicy server certificate.
    - mutual_auth When set to "mutual_auth", mutual authentication takes place between the SVM and the FPolicy server. This means authentication of the FPolicy server by the SVM along with authentication of the SVM by the FPolicy server. With this option, before creating the FPolicy external engine, the administrator must install the public certificate of the certificate authority (CA) that signed the FPolicy server certificate along with the public certificate and key file for authentication of the SVM.

    Valid choices:

    - no_auth
    - server_auth
    - mutual_auth
  `status_request_interval: str GET POST PATCH`

    Specifies the ISO-8601 interval time for a storage appliance to query a status request from an FPolicy server. The allowed range is between 0 to 50 seconds.

    Example: PT10S

  `type: str GET POST PATCH`

    The notification mode determines what ONTAP does after sending notifications to FPolicy servers. The possible values are:

        * synchronous  - After sending a notification, wait for a response from the FPolicy server.
        * asynchronous - After sending a notification, file request processing continues.

    Valid choices:

    - synchronous
    - asynchronous